@@ -225,6 +225,13 @@ where
     }
 }
 
+pub fn endpoint_not_found<D: fmt::Display>(service_type: D) -> Error {
+    Error::new(
+        ErrorKind::EndpointNotFound,
+        format!("Endpoint for service {} was not found", service_type),
+    )
+}
+
 pub mod url {
     //! Handy primitives for working with URLs.
 
@@ -267,21 +274,3 @@ pub mod url {
         url
     }
 }
-
-#[cfg(test)]
-pub mod test {
-    //! Common primitives for testing.
-
-    use reqwest::IntoUrl;
-
-    use super::super::auth::NoAuth;
-    use super::super::session::Session;
-
-    /// Create a session with fake authentication.
-    pub fn new_session<U: IntoUrl>(endpoint: U) -> Session {
-        let auth = NoAuth::new(endpoint).expect("Invalid URL in tests");
-        Session::new(auth)
-    }
-
-    pub const URL: &'static str = "https://127.0.0.1:5000/";
-}
